SupabaseGenConfig class

Constructors

SupabaseGenConfig({required String host, required int port, required String database, required String username, required String password, required bool ssl, required String outputDirectory, List<String> excludeTables = const ['migrations', 'schema_migrations'], List<String> includeTables = const [], List<String> excludeReferences = const [], bool generateForAllTables = true, bool generateModels = true, String modelsFileName = 'models.dart', String? modelPrefix = '', String? modelSuffix = 'Model', bool useNullSafety = true, String? repositorySuffix = 'Repository', String databaseName = 'app_db.sqlite', bool generateSupabaseSelectBuilders = false, String supabaseSelectBuildersFilePath = 'lib/database/supabase_select_builders.g.dart', String generatedSupabaseSchemaDartFilePath = 'lib/database/supabase_schema.dart', bool generateSqliteMigrations = false, String sqliteMigrationsSubDir = 'assets/sqlite_migrations', String schemaRegistryFilePath = 'lib/database/schema_registry.dart', String databaseImportPath = '../database/my_database.dart', List<String> sanitizationEndings = const ['_id', '_fk'], bool generateClientManagers = false, bool useRiverpod = true, String providersSubDir = 'providers', bool generateProviders = true, bool generateAuthentication = true, String authProfileTableName = 'profiles', bool generateBackgroundServices = true})
const
SupabaseGenConfig.fromYaml(Map<String, dynamic> yaml, Map<String, dynamic> envVars)
factory

Properties

authProfileTableName → String
final
database → String
final
databaseImportPath → String
final
databaseName → String
final
excludeReferences → List<String>
final
excludeTables → List<String>
final
generateAuthentication → bool
final
generateBackgroundServices → bool
final
generateClientManagers → bool
final
generatedSupabaseSchemaDartFilePath → String
final
generateForAllTables → bool
final
generateModels → bool
final
generateProviders → bool
final
generateSqliteMigrations → bool
final
generateSupabaseSelectBuilders → bool
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
includeTables → List<String>
final
modelPrefix → String?
final
modelsFileName → String
final
modelsFilePath → String
no setter
modelSuffix → String?
final
outputDirectory → String
final
password → String
final
port → int
final
providersDirectoryPath → String
no setter
providersSubDir → String
final
repositorySuffix → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sanitizationEndings → List<String>
final
schemaRegistryFilePath → String
final
sqliteMigrationsDirectory → String
no setter
sqliteMigrationsSubDir → String
final
ssl → bool
final
supabaseSelectBuildersFilePath → String
final
useNullSafety → bool
final
useRiverpod → bool
final
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited